@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,7 +25,7 @@ class RichTextExternalComposerTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit RichTextExternalComposerTest(QObject *parent = Q_NULLPTR);
+    explicit RichTextExternalComposerTest(QObject *parent = nullptr);
     ~RichTextExternalComposerTest();
 private Q_SLOTS:
     void shouldHaveDefaultValue();
