@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,8 +22,7 @@
 
 #include <QWidget>
 #include "kpimtextedit_export.h"
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class RichTextComposerWidgetPrivate;
 class RichTextComposer;
 /**
@@ -34,7 +33,7 @@ class KPIMTEXTEDIT_EXPORT RichTextComposerWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit RichTextComposerWidget(QWidget *parent = Q_NULLPTR);
+    explicit RichTextComposerWidget(QWidget *parent = nullptr);
     ~RichTextComposerWidget();
 
     KPIMTextEdit::RichTextComposer *richTextComposer() const;
