@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -41,7 +41,7 @@ class KPIMTEXTEDIT_EXPORT RichTextEditor : public QTextEdit
     Q_PROPERTY(bool webShortcutSupport READ webShortcutSupport WRITE setWebShortcutSupport)
 public:
     explicit RichTextEditor(QWidget *parent = nullptr);
-    ~RichTextEditor();
+    ~RichTextEditor() override;
     enum SupportFeature {
         None = 0,
         Search = 1,
@@ -144,6 +144,7 @@ private:
     void deleteWordForward();
     void highlightWord(int length, int pos);
     void checkSpelling(bool force);
+    void moveLineUpDown(bool moveUp);
     class RichTextEditorPrivate;
     RichTextEditorPrivate *const d;
 };
