@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,13 +22,12 @@
 
 #include <QComboBox>
 #include <QLocale>
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class TextToSpeechLanguageComboBox : public QComboBox
 {
     Q_OBJECT
 public:
-    explicit TextToSpeechLanguageComboBox(QWidget *parent = Q_NULLPTR);
+    explicit TextToSpeechLanguageComboBox(QWidget *parent = nullptr);
     ~TextToSpeechLanguageComboBox();
     void selectLocaleName(const QString &localeName);
     void updateAvailableLocales(const QVector<QLocale> &locales, const QLocale &current);
